==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/operationalinsights/kotlin/inputs/ColumnArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.operationalinsights.kotlin.inputs

import com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs.builder
import com.pulumi.azurenative.operationalinsights.kotlin.enums.ColumnDataTypeHintEnum
import com.pulumi.azurenative.operationalinsights.kotlin.enums.ColumnTypeEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Table column.
 * @property dataTypeHint Column data type logical hint.
 * @property description Column description.
 * @property displayName Column display name.
 * @property name Column name.
 * @property type Column data type.
 */
public data class ColumnArgs(
    public val dataTypeHint: Output<Either<String, ColumnDataTypeHintEnum>>? = null,
    public val description: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val name: Output<String>? = null,
    public val type: Output<Either<String, ColumnTypeEnum>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs> {
    override fun toJava(): com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs =
        com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs.builder()
            .dataTypeHint(
                dataTypeHint?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .description(description?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ColumnArgs].
 */
@PulumiTagMarker
public class ColumnArgsBuilder internal constructor() {
    private var dataTypeHint: Output<Either<String, ColumnDataTypeHintEnum>>? = null

    private var description: Output<String>? = null

    private var displayName: Output<String>? = null

    private var name: Output<String>? = null

    private var type: Output<Either<String, ColumnTypeEnum>>? = null

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("xnyidlgbfmlwoacw")
    public suspend fun dataTypeHint(`value`: Output<Either<String, ColumnDataTypeHintEnum>>) {
        this.dataTypeHint = value
    }

    /**
     * @param value Column description.
     */
    @JvmName("vunhnwpnhdkhndjm")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Column display name.
     */
    @JvmName("rnqpbnupgnagqqru")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value Column name.
     */
    @JvmName("bkqnhmjrrhrimbwa")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Column data type.
     */
    @JvmName("awhauaqpgraibnhb")
    public suspend fun type(`value`: Output<Either<String, ColumnTypeEnum>>) {
        this.type = value
    }

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("mcodxsgjojeafqse")
    public suspend fun dataTypeHint(`value`: Either<String, ColumnDataTypeHintEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataTypeHint = mapped
    }

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("fbldyhqfnlveqool")
    public fun dataTypeHint(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ColumnDataTypeHintEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataTypeHint = mapped
    }

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("nhnbyxdthkrbyafb")
    public fun dataTypeHint(`value`: ColumnDataTypeHintEnum) {
        val toBeMapped = Either.ofRight<String, ColumnDataTypeHintEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataTypeHint = mapped
    }

    /**
     * @param value Column description.
     */
    @JvmName("uyslcnnhyfujwntv")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Column display name.
     */
    @JvmName("xmrhmsspicelpjub")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value Column name.
     */
    @JvmName("hshkhefxndbluxwm")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Column data type.
     */
    @JvmName("plqtxvrvmcmuupga")
    public suspend fun type(`value`: Either<String, ColumnTypeEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Column data type.
     */
    @JvmName("aksmpnreprkkxrqc")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ColumnTypeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Column data type.
     */
    @JvmName("sjttxjvcfybcqaiy")
    public fun type(`value`: ColumnTypeEnum) {
        val toBeMapped = Either.ofRight<String, ColumnTypeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ColumnArgs = ColumnArgs(
        dataTypeHint = dataTypeHint,
        description = description,
        displayName = displayName,
        name = name,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/operationalinsights/kotlin/inputs/ColumnArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.operationalinsights.kotlin.inputs

import com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs.builder
import com.pulumi.azurenative.operationalinsights.kotlin.enums.ColumnDataTypeHintEnum
import com.pulumi.azurenative.operationalinsights.kotlin.enums.ColumnTypeEnum
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Table column.
 * @property dataTypeHint Column data type logical hint.
 * @property description Column description.
 * @property displayName Column display name.
 * @property name Column name.
 * @property type Column data type.
 */
public data class ColumnArgs(
    public val dataTypeHint: Output<Either<String, ColumnDataTypeHintEnum>>? = null,
    public val description: Output<String>? = null,
    public val displayName: Output<String>? = null,
    public val name: Output<String>? = null,
    public val type: Output<Either<String, ColumnTypeEnum>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs> {
    override fun toJava(): com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs =
        com.pulumi.azurenative.operationalinsights.inputs.ColumnArgs.builder()
            .dataTypeHint(
                dataTypeHint?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .description(description?.applyValue({ args0 -> args0 }))
            .displayName(displayName?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ColumnArgs].
 */
@PulumiTagMarker
public class ColumnArgsBuilder internal constructor() {
    private var dataTypeHint: Output<Either<String, ColumnDataTypeHintEnum>>? = null

    private var description: Output<String>? = null

    private var displayName: Output<String>? = null

    private var name: Output<String>? = null

    private var type: Output<Either<String, ColumnTypeEnum>>? = null

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("wlybkncclkvcgrou")
    public suspend fun dataTypeHint(`value`: Output<Either<String, ColumnDataTypeHintEnum>>) {
        this.dataTypeHint = value
    }

    /**
     * @param value Column description.
     */
    @JvmName("hnhevjkkpqnlgtvn")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Column display name.
     */
    @JvmName("mxrnnmbuvlqgmjse")
    public suspend fun displayName(`value`: Output<String>) {
        this.displayName = value
    }

    /**
     * @param value Column name.
     */
    @JvmName("yhooygyllbhqtryy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Column data type.
     */
    @JvmName("lpgxdhrjgirsjblu")
    public suspend fun type(`value`: Output<Either<String, ColumnTypeEnum>>) {
        this.type = value
    }

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("dgbsaiafegudpdsx")
    public suspend fun dataTypeHint(`value`: Either<String, ColumnDataTypeHintEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataTypeHint = mapped
    }

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("ldsntjlxarxhpxgn")
    public fun dataTypeHint(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ColumnDataTypeHintEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataTypeHint = mapped
    }

    /**
     * @param value Column data type logical hint.
     */
    @JvmName("pajbpwxqwbegmqxh")
    public fun dataTypeHint(`value`: ColumnDataTypeHintEnum) {
        val toBeMapped = Either.ofRight<String, ColumnDataTypeHintEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataTypeHint = mapped
    }

    /**
     * @param value Column description.
     */
    @JvmName("qgvsxovqyibyanao")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Column display name.
     */
    @JvmName("iymhjsdigfdghivc")
    public suspend fun displayName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.displayName = mapped
    }

    /**
     * @param value Column name.
     */
    @JvmName("wdiuahlbytjkpkee")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Column data type.
     */
    @JvmName("odotfuotsbphlagi")
    public suspend fun type(`value`: Either<String, ColumnTypeEnum>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Column data type.
     */
    @JvmName("bdplipagteoglfkc")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ColumnTypeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Column data type.
     */
    @JvmName("jadtbtxjfipgckgc")
    public fun type(`value`: ColumnTypeEnum) {
        val toBeMapped = Either.ofRight<String, ColumnTypeEnum>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ColumnArgs = ColumnArgs(
        dataTypeHint = dataTypeHint,
        description = description,
        displayName = displayName,
        name = name,
        type = type,
    )
}
